var searchData=
[
  ['val_5fat_0',['val_at',['../classgko_1_1matrix_1_1Ell.html#a000e6a621aca6cb0c1b5cf8b5bf7c63e',1,'gko::matrix::Ell::val_at(size_type row, size_type idx) noexcept'],['../classgko_1_1matrix_1_1Ell.html#a3591fa0ab2ec09b43a15b0f0649d8ea3',1,'gko::matrix::Ell::val_at(size_type row, size_type idx) const noexcept'],['../classgko_1_1matrix_1_1Sellp.html#a11d6b079410d557a299452f1013a5b25',1,'gko::matrix::Sellp::val_at(size_type row, size_type slice_set, size_type idx) noexcept'],['../classgko_1_1matrix_1_1Sellp.html#ad4bb228252469da6e57eb38edd66fb8e',1,'gko::matrix::Sellp::val_at(size_type row, size_type slice_set, size_type idx) const noexcept']]],
  ['validate_5fapplication_5fparameters_1',['validate_application_parameters',['../classgko_1_1batch_1_1BatchLinOp.html#a86f750708b3f8cdff5830276cb339ece',1,'gko::batch::BatchLinOp::validate_application_parameters(const MultiVector&lt; ValueType &gt; *b, MultiVector&lt; ValueType &gt; *x) const'],['../classgko_1_1batch_1_1BatchLinOp.html#a8f14ea87e7698b874d335774eb454e12',1,'gko::batch::BatchLinOp::validate_application_parameters(const MultiVector&lt; ValueType &gt; *alpha, const MultiVector&lt; ValueType &gt; *b, const MultiVector&lt; ValueType &gt; *beta, MultiVector&lt; ValueType &gt; *x) const']]],
  ['value_5flist_2',['value_list',['../structgko_1_1syn_1_1value__list.html',1,'gko::syn']]],
  ['value_5flist_3c_20int_20_3e_3',['value_list&lt; int &gt;',['../structgko_1_1syn_1_1value__list.html',1,'gko::syn']]],
  ['value_5flist_3c_20t_2c_20values_2e_2e_2e_20_3e_4',['value_list&lt; T, Values... &gt;',['../structgko_1_1syn_1_1value__list.html',1,'gko::syn']]],
  ['value_5flist_3c_20t_2c_20values1_2e_2e_2e_2c_20values2_2e_2e_2e_20_3e_5',['value_list&lt; T, Values1..., Values2... &gt;',['../structgko_1_1syn_1_1value__list.html',1,'gko::syn']]],
  ['value_5ftype_6',['value_type',['../classgko_1_1array.html#a9a8aebb3d68396889cf98ca877808549',1,'gko::array::value_type'],['../classgko_1_1accessor_1_1row__major.html#a687bda931be92c31abf02965fa72ceba',1,'gko::accessor::row_major::value_type']]],
  ['valuemismatch_7',['ValueMismatch',['../classgko_1_1ValueMismatch.html',1,'gko::ValueMismatch'],['../classgko_1_1ValueMismatch.html#a505714cad59257a24aa712a8d3449e4a',1,'gko::ValueMismatch::ValueMismatch()']]],
  ['variable_20declarations_8',['Variable declarations',['../contributing_guidelines.html#autotoc_md46',1,'']]],
  ['variables_9',['Variables',['../contributing_guidelines.html#autotoc_md33',1,'']]],
  ['vector_10',['Vector',['../classgko_1_1experimental_1_1distributed_1_1Vector.html',1,'gko::experimental::distributed']]],
  ['vector_3c_20previous_5fprecision_3c_20valuetype_20_3e_20_3e_11',['Vector&lt; previous_precision&lt; ValueType &gt; &gt;',['../classgko_1_1experimental_1_1distributed_1_1Vector.html',1,'gko::experimental::distributed']]],
  ['vector_3c_20to_5fcomplex_3c_20value_5ftype_20_3e_20_3e_12',['Vector&lt; to_complex&lt; value_type &gt; &gt;',['../classgko_1_1experimental_1_1distributed_1_1Vector.html',1,'gko::experimental::distributed']]],
  ['vector_3c_20valuetype_20_3e_13',['Vector&lt; ValueType &gt;',['../classgko_1_1experimental_1_1distributed_1_1Vector.html',1,'gko::experimental::distributed']]],
  ['version_14',['version',['../structgko_1_1version.html',1,'gko']]],
  ['version_5finfo_15',['version_info',['../classgko_1_1version__info.html',1,'gko']]],
  ['view_16',['view',['../classgko_1_1array.html#aac2a7c2d59045e56fb751b18712a4635',1,'gko::array']]],
  ['view_5fdeleter_17',['view_deleter',['../classgko_1_1array.html#a377a6aaf5ee6c2747781b889eea6c226',1,'gko::array']]],
  ['void_5ft_18',['void_t',['../namespacegko_1_1xstd.html#a2d53b45325a9d6c46906d80caf180869',1,'gko::xstd']]],
  ['vs_20functions_19',['Use of macros vs functions',['../contributing_guidelines.html#autotoc_md49',1,'']]]
];
